<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0">
<context>
    <name>DigitalClockWdg</name>
    <message>
        <source>Digital Clock</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <source>Digital Clock settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Width</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Height</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Digits Color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>24H</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>12H (AM/PM)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Military</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>About</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>About Qt</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Font</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Default (LCD)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>About DigiClock</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>B</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>I</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>12:48</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Display</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Transparency</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>System</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Format</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Seconds</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Blinking</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Time Zone</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show City name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show Date</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>full date</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open Clock app on Click</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rotation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enable Autorotation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fixed Corner</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Top Left</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Top Right</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Bottom Left</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Bottom Right</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>DigiClock</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Developed with</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Desktop widget, showing digital time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Send reports to:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
